Learn R Programming

mlr3spatiotempcv (version 0.1.1)

autoplot.ResamplingSptCVCstf: Visualization Functions for SptCV Cstf Methods.

Description

Generic S3 plot() and autoplot() (ggplot2) methods.

Usage

# S3 method for ResamplingSptCVCstf
autoplot(
  object,
  task,
  fold_id = NULL,
  plot_as_grid = TRUE,
  train_color = "#0072B5",
  test_color = "#E18727",
  tickformat_date = "%Y-%m",
  crs = NULL,
  nticks_x = 3,
  nticks_y = 3,
  point_size = 3,
  axis_label_fontsize = 11,
  ...
)

# S3 method for ResamplingRepeatedSptCVCstf autoplot( object, task, fold_id = NULL, repeats_id = NULL, plot_as_grid = TRUE, train_color = "#0072B5", test_color = "#E18727", tickformat_date = "%Y-%m", crs = NULL, nticks_x = 3, nticks_y = 3, point_size = 3, axis_label_fontsize = 11, ... )

# S3 method for ResamplingSptCVCstf plot(x, ...)

# S3 method for ResamplingRepeatedSptCVCstf plot(x, ...)

Arguments

object

[Resampling] mlr3 spatial resampling object of class ResamplingSptCVCstf or ResamplingRepeatedSptCVCstf.

task

[TaskClassifST]/[TaskRegrST] mlr3 task object.

fold_id

[numeric] Fold IDs to plot.

plot_as_grid

[logical(1)] Should a gridded plot using via patchwork be created? If FALSE only a list with all ggplot2 resamplings is returned. Only applies if a numeric vector is passed to argument fold_id.

train_color

[character(1)] The color to use for the training set observations.

test_color

[character(1)] The color to use for the test set observations.

tickformat_date

[character] Date format for z-axis.

crs

[character] EPSG code of the CRS for x and y axes. If not set, EPSG 4326 (WGS84) is used.

nticks_x

[integer] Number of x axis breaks.

nticks_y

[integer] Number of y axis breaks.

point_size

[numeric] Point size of markers.

axis_label_fontsize

[integer] Font size of axis labels.

...

Not used.

repeats_id

[numeric] Repetition ID to plot.

x

[Resampling] mlr3 spatial resampling object of class ResamplingSptCVCstf or ResamplingRepeatedSptCVCstf.

Examples

Run this code
# NOT RUN {
if (mlr3misc::require_namespaces(c("sf", "skmeans", "plotly"), quietly = TRUE)) {
  library(mlr3)
  library(mlr3spatiotempcv)
  task_st = tsk("cookfarm")
  resampling = rsmp("sptcv_cstf", folds = 5, time_var = "Date")
  resampling$instantiate(task_st)

  # plot
  autoplot(resampling, task_st)
  autoplot(resampling, task_st, 1)
  autoplot(resampling, task_st, c(1, 2))
}
# }

Run the code above in your browser using DataLab