Extends the mlr3 ML framework with spatio-temporal resampling methods to account for the presence of spatiotemporal autocorrelation (STAC) in predictor variables. STAC may cause highly biased performance estimates in cross-validation if ignored.
Book on mlr3: https://mlr3book.mlr-org.com
Use cases and examples: https://mlr3gallery.mlr-org.com
More classification and regression tasks: mlr3data
Connector to OpenML: mlr3oml
More classification and regression learners: mlr3learners
Even more learners: https://github.com/mlr-org/mlr3extralearners
Preprocessing and machine learning pipelines: mlr3pipelines
Tuning of hyperparameters: mlr3tuning
Visualizations for many mlr3 objects: mlr3viz
Survival analysis and probabilistic regression: mlr3proba
Cluster analysis: mlr3cluster
Feature selection filters: mlr3filters
Feature selection wrappers: mlr3fselect
Interface to real (out-of-memory) data bases: mlr3db
Performance measures as plain functions: mlr3measures
Spatiotemporal resampling methods: mlr3spatiotempcv
Parallelization framework: future
Progress bars: progressr
Schratz P, Muenchow J, Iturritxa E, Richter J, Brenning A (2019). “Hyperparameter tuning and performance assessment of statistical and machine-learning algorithms using spatial data.” Ecological Modelling, 406, 109--120. 10.1016/j.ecolmodel.2019.06.002.
Useful links: